==> nbsite-0.7.0a8.tar.gz: nbsite-0.7.0a8/README.md <==
<img src="doc/_static/nbsite-logo.png" height=150><br>

-----------------

# NBSite: Build a tested, sphinx-based website from notebooks

|    |    |
| --- | --- |
| Build Status | [![Build Status](https://github.com/pyviz-dev/nbsite/workflows/tests/badge.svg)](https://github.com/pyviz-dev/nbsite/actions?query=workflow%3Atests)
| Coverage | [![codecov](https://codecov.io/gh/pyviz-dev/nbsite/branch/master/graph/badge.svg)](https://codecov.io/gh/pyviz-dev/nbsite) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/pyviz-dev/nbsite.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz-dev/nbsite/tags) |
| Latest release | [![Github release](https://img.shields.io/github/release/pyviz-dev/nbsite.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz-dev/nbsite/releases) [![PyPI version](https://img.shields.io/pypi/v/nbsite.svg?colorB=cc77dd)](https://pypi.python.org/pypi/nbsite) [![nbsite version](https://img.shields.io/conda/v/pyviz/nbsite.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/nbsite) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/nbsite.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/nbsite) [![defaults version](https://img.shields.io/conda/v/anaconda/nbsite.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/nbsite) |
| Docs | [![gh-pages](https://img.shields.io/github/last-commit/pyviz/nbsite/gh-pages.svg)](https://github.com/pyviz/nbsite/tree/gh-pages) [![site](https://img.shields.io/website-up-down-green-red/https/nbsite.pyviz.org.svg)](https://nbsite.pyviz.org) |

## What is it?

NBSite lets you build a website from a set of notebooks plus a minimal
amount of config. Sites built with nbsite include
[pyviz.org](https://pyviz.org),
[datashader.org](https://datashader.org/), and [hvplot.pyviz.org](https:/hvplot.pyviz.org).

The idea behind nbsite is that notebooks can simultaneously be
documentation (things you want to tell people about), examples (a
starting point for people to run and use themselves), and test cases.

This project is currently an early work in progress. See the
documentation at [nbsite.pyviz.org](https://nbsite.pyviz.org) for
more information.


## About PyViz

NBSite is part of the PyViz initiative for making Python-based visualization tools work well together.
See [pyviz.org](https://pyviz.org) for related packages that you can use with NBSite and
[status.pyviz.org](https://status.pyviz.org) for the current status of each PyViz project.

==> nbsite-0.8.0a16.tar.gz: nbsite-0.8.0a16/README.md <==
<img src="doc/_static/nbsite-logo.png" height=150><br>

-----------------

# NBSite: Build a tested, sphinx-based website from notebooks

|    |    |
| --- | --- |
| Build Status | [![Build Status](https://github.com/pyviz-dev/nbsite/workflows/tests/badge.svg)](https://github.com/pyviz-dev/nbsite/actions?query=workflow%3Atests)
| Coverage | [![codecov](https://codecov.io/gh/pyviz-dev/nbsite/branch/master/graph/badge.svg)](https://codecov.io/gh/pyviz-dev/nbsite) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/pyviz-dev/nbsite.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz-dev/nbsite/tags) |
| Latest release | [![Github release](https://img.shields.io/github/release/pyviz-dev/nbsite.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz-dev/nbsite/releases) [![PyPI version](https://img.shields.io/pypi/v/nbsite.svg?colorB=cc77dd)](https://pypi.python.org/pypi/nbsite) [![nbsite version](https://img.shields.io/conda/v/pyviz/nbsite.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/nbsite) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/nbsite.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/nbsite) [![defaults version](https://img.shields.io/conda/v/anaconda/nbsite.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/nbsite) |
| Docs | [![gh-pages](https://img.shields.io/github/last-commit/pyviz/nbsite/gh-pages.svg)](https://github.com/pyviz/nbsite/tree/gh-pages) [![site](https://img.shields.io/website-up-down-green-red/https/nbsite.pyviz.org.svg)](https://nbsite.pyviz.org) |

## What is it?

NBSite lets you build a website from a set of notebooks plus a minimal
amount of config. Sites built with nbsite include
[holoviz.org](https://holoviz.org/),
[datashader.org](https://datashader.org/), and [hvplot.holoviz.org](https://hvplot.holoviz.org/).

The idea behind nbsite is that notebooks can simultaneously be
documentation (things you want to tell people about), examples (a
starting point for people to run and use themselves), and test cases.

This project is currently an early work in progress. See the
documentation at [nbsite.holoviz.org](https://nbsite.holoviz.org/) for
more information.


## About HoloViz

NBSite is part of the HoloViz initiative for making Python-based visualization tools work well together.
See [holoviz.org](https://holoviz.org/) for related packages that you can use with NBSite and
[status.holoviz.org](https://status.holoviz.org/) for the current status of each HoloViz project.
